<?php

/* Reminder: always indent with 4 spaces (no tabs). */
// +---------------------------------------------------------------------------+
// | HTTP_REFERER Plugin for Geeklog - The Ultimate Weblog                     |
// +---------------------------------------------------------------------------+
// | install.php                                                               |
// |                                                                           |
// | This file installs and removes the data structures for the HTTP_REFERER   |
// | plugin for Geeklog.                                                       |
// +---------------------------------------------------------------------------+
// | Copyright (C) 2003 by the following authors:                              |
// |                                                                           |
// | Authors: Michael Jervis   - mike@fuckingbrit.com                          |
// +---------------------------------------------------------------------------+
// |                                                                           |
// | This program is free software; you can redistribute it and/or             |
// | modify it under the terms of the GNU General Public License               |
// | as published by the Free Software Foundation; either version 2            |
// | of the License, or (at your option) any later version.                    |
// |                                                                           |
// | This program is distributed in the hope that it will be useful,           |
// | but WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             |
// | GNU General Public License for more details.                              |
// |                                                                           |
// | You should have received a copy of the GNU General Public License         |
// | along with this program; if not, write to the Free Software Foundation,   |
// | Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.           |
// |                                                                           |
// +---------------------------------------------------------------------------+
//
// $Log: install.php,v $
// Revision 1.6  2005/02/03 19:26:30  themike
// version number updates
//

require_once('../../../lib-common.php');
require_once($_CONF['path'] . 'plugins/http_referer/language/english.php');
require_once($_CONF['path'] . 'plugins/http_referer/config.php');
require_once($_CONF['path'] . 'plugins/http_referer/functions.inc');

// Only let Root users access this page
if (!SEC_inGroup('Root')) {
    // Someone is trying to illegally access this page
    COM_errorLog("Someone has tried to illegally access the HTTP_REFERER install/uninstall page.  User id: {$_USER['uid']}, Username: {$_USER['username']}, IP: $REMOTE_ADDR",1);
    $display = COM_siteHeader();
    $display .= COM_startBlock($LANG_HR['access_denied']);
    $display .= $LANG_HR['access_denied_msg'];
    $display .= COM_endBlock();
    $display .= COM_siteFooter();
    echo $display;
    exit;
}

/**
* Puts the datastructures for this plugin into the Geeklog database
*
*/
function plugin_install_httpreferer()
{
    global $_TABLES, $_CONF, $_HR_CONF;

    COM_errorLog('Attempting to install the HTTP_REFERER Plugin',1);
    // Installs the Journal plugin
    $createsql = "CREATE TABLE {$_TABLES['http_referer']} ("
        . "id int(3) unsigned NOT NULL auto_increment,"
        . "referer varchar(255) DEFAULT '' NOT NULL,"
        . "ipaddress varchar(15) NOT NULL,"
        . "tstamp datetime default NULL,"
        . "PRIMARY KEY (id)"
        . ")";
    COM_errorLog('Attempting to install HTTP_REFERER table for HTTP_REFERER plugin',1);
    DB_query($createsql,1);

    if (DB_error()) {
        return false;
    }
    COM_errorLog('...success',1);
    $steps['createtablereferer'] = 1;

    // Create the search phrase table
    $createsql = "CREATE TABLE {$_TABLES['http_referer_phrases']} ("
        . "phrase varchar(255) DEFAULT '' NOT NULL,"
        . "counthits int(3) unsigned DEFAULT 1 NOT NULL,"
        . "PRIMARY KEY (phrase)"
        . ")";

    COM_errorLog("Attempting to create table http_referer_phrases for HTTP_REFERER plugin", 1);
    DB_query($createsql,1);

    if (DB_error()) {
        return false;
    }
    COM_errorLog('...success',1);
    $steps['createtable2'] = 1;

     // Create the search word table
    $createsql = "CREATE TABLE {$_TABLES['http_referer_words']} ("
        . "phrase varchar(255) DEFAULT '' NOT NULL,"
        . "counthits int(3) unsigned DEFAULT 1 NOT NULL,"
        . "PRIMARY KEY (phrase)"
        . ")";

    COM_errorLog("Attempting to create table http_referer_words for HTTP_REFERER plugin", 1);
    DB_query($createsql,1);

    if (DB_error()) {
        return false;
    }
    COM_errorLog('...success',1);
    $steps['createtable3'] = 1;

    // Create the Journal admin security group
    COM_errorLog("Attempting to create HTTP_REFERER admin group", 1);
    DB_query("INSERT INTO {$_TABLES['groups']} (grp_name, grp_descr) "
        . "VALUES ('HTTP_REFERER Admin Group', 'Users in this group can view/delete the HTTP_REFERERs')",1);
    if (DB_error()) {
        plugin_uninstall_http_referer($steps);
        return false;
        exit;
    }
    COM_errorLog('...success',1);
    $steps['insertgroup'] = 1;

    $group_id = DB_getItem($_TABLES['groups'], 'grp_id', "grp_name = 'HTTP_REFERER Admin Group'");

    // Add Journal features
    COM_errorLog('Attempting to add httpreferer.list feature',1);
    DB_query("INSERT INTO {$_TABLES['features']} (ft_name, ft_descr) "
        . "VALUES ('httpreferer.list','Access to HTTP_REFERER list')",1);
    if (DB_error()) {
        plugin_uninstall_http_referer($steps);
        return false;
        exit;
    }
    $list_id = DB_insertId();
    COM_errorLog('...success',1);
    $steps['insertedfeaturelist'] = 1;

    COM_errorLog('Attempting to add httpreferer.delete feature',1);
    DB_query("INSERT INTO {$_TABLES['features']} (ft_name, ft_descr) "
        . "VALUES ('httpreferer.delete','Ability to delete HTTP_REFERERS')",1);
    if (DB_error()) {
        plugin_uninstall_http_referer($steps);
        return false;
        exit;
    }
    $delete_id = DB_insertId();
    COM_errorLog('...success',1);
    $steps['insertedfeaturedelete'] = 1;

    // Now add the features to the group
    COM_errorLog('Attempting to give HTTP_REFERER Admin group access to httpreferer.list feature',1);
    DB_query("INSERT INTO {$_TABLES['access']} (acc_ft_id, acc_grp_id) VALUES ($list_id, $group_id)");
    if (DB_error()) {
        plugin_uninstall_http_referer($steps);
        return false;
        exit;
    }
    COM_errorLog('...success',1);
    $steps['addedlisttogroup'] = 1;

    COM_errorLog('Attempting to give HTTP_REFERER Admin group access to httpreferer.delete feature',1);
    DB_query("INSERT INTO {$_TABLES['access']} (acc_ft_id, acc_grp_id) VALUES ($delete_id, $group_id)",1);
    if (DB_error()) {
        plugin_uninstall_http_referer($steps);
        return false;
        exit;
    }
    COM_errorLog('...success',1);
    $steps['addeddeletetogroup'] = 1;

    // OK, now give Root users access to this plugin now! NOTE: Root group should always be 1
    COM_errorLog('Attempting to give all users in Root group access HTTP_REFERER admin group',1);
    DB_query("INSERT INTO {$_TABLES['group_assignments']} VALUES ($group_id, NULL, 1)");
    if (DB_error()) {
        plugin_uninstall_http_referer($steps);
        return false;
        exit;
    }
    COM_errorLog('...success',1);
    $steps['addedrootuserstogroup'] = 1;

    // Register the plugin with Geeklog
    if (DB_count($_TABLES['plugins'],'pi_name','http_referer') > 0) {
        COM_errorLog('Attempting to remove HTTP_REFERER rentry prior to adding an updated entry',1);
        DB_query("DELETE FROM {$_TABLES['plugins']} WHERE pi_name = 'http_referer'");
        if (DB_error()) {
            plugin_uninstall_http_referer($steps);
            return false;
            exit;
        }
        COM_errorLog('...success',1);
    } else {
        // Only install data on a fresh installation
        // This plugin has no install data
    }

    COM_errorLog('Registering HTTP_REFERER plugin with Geeklog', 1);
    DB_delete($_TABLES['plugins'],'pi_name','http_referer');
    DB_query("INSERT INTO {$_TABLES['plugins']} (pi_name, pi_version, pi_gl_version, pi_homepage, pi_enabled) "
        . "VALUES ('http_referer', '{$_HR_CONF['version']}', '1.3.8', 'http://www.fuckingbrit.com', 1)");

    if (DB_error()) {
        plugin_uninstall_http_referer($steps);
        return false;
        exit;
    }
    COM_errorLog('...success',1);
    COM_errorLog('Succesfully installed the HTTP_REFERER Plugin!',1);

    return true;
}

/*
MAIN:  OK, I wanted to keep this simple so this is how this works.  When ran for the first
time, this file will attempt to install the datastructures immediately.  When that is complete,
it will insert a record into the Geeklog vars table (name = 'journal', value = 1) which will
lock this file from being executed at by anyone.

If you want to remove this plugin you would set the value in that record to 0 and then this script
will uninstall the plugin.  All this is outlined in the INSTALL and UNINSTALL documents.
*/

$display = COM_siteHeader();

if ( $_GET['action'] == 'install') {
    if (plugin_install_httpreferer()) {
        $display .= COM_startBlock($LANG_HR['installation_complete']);
        $display .= $LANG_HR['installation_complete_msg'];
        $display .= COM_endBlock();
    } else {
        // Error occured
        $display .= COM_startBlock($LANG_HR['installation_failed']);
        $display .= $LANG_HR['installation_failed_msg'];
        $display .= COM_endBlock();
    }
} elseif ( $_GET['action'] == 'uninstall' ) {
    if (plugin_uninstall_http_referer()) {
        // Uninstall worked
        $display .= COM_startBlock($LANG_HR['uninstall_complete']);
        $display .= $LANG_HR['uninstall_complete_msg'];
        $display .= COM_endBlock();
    } else {
        // Uninstall failed
        $display .= COM_startBlock($LANG_HR['uninstall_failed']);
        $display .= $LANG_HR['uninstall_failed_msg'];
        $display .= COM_endBlock();
    }
}

$display .= COM_siteFooter();

echo $display;

?>
