<?php

/* Reminder: always indent with 4 spaces (no tabs). */
// +---------------------------------------------------------------------------+
// | HTTP_REFERER Plugin     for Geeklog - The Ultimate Weblog                 |
// +---------------------------------------------------------------------------+
// | functions.inc                                                             |
// |                                                                           |
// | This file does two things: 1) it implements the necessary Geeklog Plugin  |
// | API method and 2) implements all the common code needed by the            |
// | HTTP_REFERERS PHP files                                                   |
// +---------------------------------------------------------------------------+
// | Copyright (C) 2003 by the following authors:                              |
// |                                                                           |
// | Authors: Michael Jervis   - mike@fuckingbrit.com                          |
// |            Jeff Bearer    - jeffbearer@yahoo.com                          |
// +---------------------------------------------------------------------------+
// |                                                                           |
// | This program is free software; you can redistribute it and/or             |
// | modify it under the terms of the GNU General Public License               |
// | as published by the Free Software Foundation; either version 2            |
// | of the License, or (at your option) any later version.                    |
// |                                                                           |
// | This program is distributed in the hope that it will be useful,           |
// | but WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             |
// | GNU General Public License for more details.                              |
// |                                                                           |
// | You should have received a copy of the GNU General Public License         |
// | along with this program; if not, write to the Free Software Foundation,   |
// | Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.           |
// |                                                                           |
// +---------------------------------------------------------------------------+
// $Log: functions.inc,v $
// Revision 1.10  2005/01/30 19:39:35  themike
// Numerious fixes
//
// Revision 1.9  2004/12/17 20:20:37  themike
// + SPAMX filtering of http_referer
// + Pagination of search phrase/words.
//
// Revision 1.8  2003/10/19 10:51:38  themike
// Fixed clean word error
//
// Revision 1.7  2003/10/19 10:02:57  themike
// Fixed str_replace
// Improved word logging (trims words not phrases, trims words better)
//
// Revision 1.6  2003/10/17 16:20:40  themike
// Added phpblocks from Jeff Bearer, plus fixed the word ignore to be case-insenstive.
//
// Revision 1.4  2003/10/07 10:29:59  themike
// Fixed timestamp, improved display of HTTP_REFERERS
// Fixed MSN Search
//
// Revision 1.3  2003/10/04 16:16:25  themike
// Check in of 1.1
//

$langfile = $_CONF['path'] . 'plugins/http_referer/language/' . $_CONF['language'] . '.php';

if (file_exists ($langfile)) {
    include ($langfile);
} else {
    include ($_CONF['path'] . 'plugins/http_referer/language/english.php');
}

include ($_CONF['path'] . 'plugins/http_referer/config.php');

// +---------------------------------------------------------------------------+
// | Geeklog Plugin API Implementations                                        |
// +---------------------------------------------------------------------------+

/**
* Geeklog is checking to see if this plugin supports comments, tell it no.
*
* NOTE: to support comments you must used the same date/time based ID for your
* widget.  In other words, to make primary keys for your plugin you should call
* makesid().  Comments are keyed off of that...it is a limitation on how Geeklog
* does comments.
*
*/
function plugin_commentsupport_http_referer()
{
    // Static Pages will not use comments
    return false;
}

/**
* This will put an option for static pages in the command and control block on
* moderation.php
*
*/
function plugin_cclabel_http_referer()
{
    global $LANG_HR, $_CONF;

    if (SEC_hasRights ('httpreferer.list,httpreferer.delete', 'OR')) {
        return array ($LANG_HR['http_referer'],
                $_CONF['site_admin_url'] . '/plugins/http_referer/index.php',
                $_CONF['site_admin_url'] . '/plugins/http_referer/icon.gif',);
    }

    return false;
}

/**
* Returns the administrative option for this plugin
*
* Adds the plugin to the Admin menu
*
* Universal Plugin:  Modify/Uncomment use it
*
* @return   array   Array containing (plugin name, plugin admin url, # of items in plugin or '')
*
*/
function plugin_getadminoption_http_referer()
{
    global $_CONF, $LANG_HR, $_TABLES;

    if (SEC_hasRights ('httpreferer.list,httpreferer.delete', 'OR')) {
        return array ($LANG_HR[http_referer], $_CONF['site_admin_url'] . '/plugins/http_referer/index.php', DB_count($_TABLES['http_referer']));
    }
}

/**
* Removes the datastructures for this plugin from the Geeklog database
*
* This may get called by the install routine to undo anything done to this
* point.  To do that, $steps will have a list of steps to undo
*
* @steps   Array    Holds all the steps that have been completed by the install
*
*/
function plugin_uninstall_http_referer($steps = '')
{
    global $_TABLES;

    // Uninstalls the static pages plugin

    if (empty($steps) OR $steps['createtablereferer'] == 1) {
        // Remove the staticpage table
        COM_errorLog('Dropping http_referers table',1);
        DB_query("DROP TABLE {$_TABLES['http_referer']}");
        COM_errorLog('...success',1);
    }

    if (empty($steps) OR $steps['createtable2'] == 1) {
        // Remove the staticpage table
        COM_errorLog('Dropping http_referers_phrases table',1);
        DB_query("DROP TABLE {$_TABLES['http_referer_phrases']}");
        COM_errorLog('...success',1);
    }

    if (empty($steps) OR $steps['createtable3'] == 1) {
        // Remove the staticpage table
        COM_errorLog('Dropping http_referers_words table',1);
        DB_query("DROP TABLE {$_TABLES['http_referer_words']}");
        COM_errorLog('...success',1);
    }


    // Remove security for this plugin

    // Remove the static page admin group
    $grp_id = DB_getItem($_TABLES['groups'], 'grp_id', "grp_name = 'HTTP_REFERER Admin Group'");

    if (empty($steps) OR $steps['insertgroup'] == 1) {
        COM_errorLog('Attempting to remove the HTTP_REFERER Admin Group', 1);
        DB_query("DELETE FROM {$_TABLES['groups']} WHERE grp_id = $grp_id");
        COM_errorLog('...success',1);
    }

    // Remove related features
    $list_id = DB_getItem($_TABLES['features'], 'ft_id', "ft_name = 'httpreferer.list'");
    $delete_id = DB_getItem($_TABLES['features'], 'ft_id', "ft_name = 'httpreferer.delete'");

    if (empty($steps) OR $steps['addedlisttogroup'] == 1) {
        // Remove access to those features
        COM_errorLog('Attempting to remove rights to httpreferer.list from all groups',1);
        DB_query("DELETE FROM {$_TABLES['access']} WHERE acc_ft_id = $list_id");
        COM_errorLog('...success',1);
    }

    if (empty($steps) OR $steps['addeddeletetogroup'] == 1) {
        // Remove access to those features
        COM_errorLog('Attempting to remove rights to httpreferer.delete from all groups',1);
        DB_query("DELETE FROM {$_TABLES['access']} WHERE acc_ft_id = $delete_id");
        COM_errorLog('...success',1);
    }

    if (empty($steps) OR $steps['addedrootuserstogroup'] == 1) {
        // Remove root users from the group
        COM_errorLog('Attempting to remove root users from admin of static pages');
        DB_query("DELETE FROM {$_TABLES['group_assignments']} WHERE ug_main_grp_id = $grp_id");
        COM_errorLog('...success',1);
    }

    if (empty($steps) OR $steps['insertedfeaturelist'] == 1) {
        COM_errorLog('Attempting to remove the httpreferer.list feature',1);
        DB_query("DELETE FROM {$_TABLES['features']} WHERE ft_id = $list_id");
        COM_errorLog('...success',1);
    }

    if (empty($steps) OR $steps['insertedfeaturedelete'] == 1) {
        COM_errorLog('Attempting to remove the httpreferer.delete feature',1);
        DB_query("DELETE FROM {$_TABLES['features']} WHERE ft_id = $delete_id");
        COM_errorLog('...success',1);
    }

    // Unregister the plugin with Geeklog
    // Always attempt to remove these entries or lib-common.php would still
    // try and read our functions.inc file ...
    COM_errorLog('Attempting to unregister the plugin from Geeklog',1);
    DB_query("DELETE FROM {$_TABLES['plugins']} WHERE pi_name = 'http_referer'");
    COM_errorLog('...success',1);

    COM_errorLog('leaving plugin_uninstall_http_referer',1);

    return true;
}

/**
  * http_referer_log()
  * Log the HTTP_REFERER to the table <prefix>Http_referer
  */
function http_referer_log()
{
    global $_CONF;
    $referer = getenv("HTTP_REFERER");

    // Ignore the following
    $urlwww = str_replace_once( 'www.', '', $_CONF['site_url'] );
    if(
        $referer == "" // No referer
        OR eregi( "^unknown", $referer ) // Unknown referer
        OR eregi( "^XXXX:\+*$", $referer) // some bollocks I keep seeing
        OR substr( $referer, 0, strlen( $_CONF['site_url'] ) ) == $_CONF['site_url'] // starts with site url
        OR substr( $referer, 0, strlen( $urlwww ) ) == $urlwww // site url with www. removed
        )
    {
    } else {
        // Searches:
        if( $_CONF['http_referer_qsp'] == 1 )
        {
            $searchEngine = http_referer_check_queries( $referer );
            if( $searchEngine  && ( $_CONF['http_referer_lse'] == 1 ) )
            {
                http_referer_insert( $referer );
            } elseif ( !$searchEngine ) {
                http_referer_insert( $referer );
            }
        } else {
            http_referer_insert( $referer );
       }
    }
}

/**
  * inserts a row into the HTTP_REFERER table
  * @param referer the referer to insert
  */
function http_referer_insert( $referer )
{
    global $_TABLES, $_CONF;
    /* Check for spam! */
    $result = PLG_checkforSpam($referer, $_CONF['spamx']);
    if( $result > 0 )
    {
    	die( 'Go to hell spam bot');
    } else {
    	$referer = substr( $referer, 0, 255 );
    	$ipaddress = $_SERVER['REMOTE_ADDR'];
    	$sql = "insert into ".$_TABLES['http_referer']." (referer, ipaddress,"
      	  . "tstamp ) VALUES ('$referer','$ipaddress',now())";
    	$result = DB_query( $sql );
    }
}

/**
  * Checks to see if a url is from a search engine, and log the search if it is.
  * @param referer the url
  */
function http_referer_check_queries( $referer )
{
    global $_CONF;
    $return = false;
    reset( $_CONF['http_referer_qss'] );
    while( list( $regexp, $qsitem ) = each( $_CONF['http_referer_qss'] ) )
    {
        if( eregi( $regexp, $referer ) )
        {
            $return = true;
            $url = parse_url( $referer );
            $querystring = $url['query'];
            $querystring = explode( "&", $querystring );
            while( list( , $value ) = each( $querystring ) )
            {
                $item = explode( "=", $value );
                if( $item[0] == $qsitem )
                {
                    if( trim( $item[1] ) != '' )
                    {
                        http_referer_log_search( $item[1] );
                    }
                }
            }
        }
    }
    return $return;
}

/**
 * Cleans a word to be just a word
 * @param $word to clean
 * @return clean word
 */
function http_referer_clean_word( $word )
{
    $word = str_replace( '+', '', $word );
    $word = str_replace( '-', '', $word );
    $word = str_replace( ',', '', $word );
    $word = str_replace( '"', '', $word );
    $word = str_replace( "'", '', $word );
    $word = trim( $word );
    return $word;
}

/**
  * Logs a search term to the db, after stripping it down.
  * @param searchTerm the search phrase to log
  */
function http_referer_log_search( $searchTerm )
{
    global $_TABLES, $_CONF;
    $searchTerm = trim( urldecode( $searchTerm ) );

    if( $_CONF['http_referer_qsw'] == 1 )
    {
        /* Log search words */
        $searchWords = explode( " ", $searchTerm );
        while( list( , $word ) = each( $searchWords ) )
        {
            if( !in_array( strtolower( $word ), $_CONF['http_referer_ignore_words'] ) &&
                ( trim( $word ) != '' ) )
            {
                $word = addslashes( http_referer_clean_word( $word ) );
                if( $word != '' )
                {
                    $result = DB_count( $_TABLES['http_referer_words'], 'phrase', $word );
                    if( $result > 0 )
                    {
                        $sql = "UPDATE {$_TABLES['http_referer_words']} SET counthits = counthits + 1 "
                         . "WHERE phrase = '$word'";
                    } else {
                        $sql = "INSERT INTO {$_TABLES['http_referer_words']} VALUES ('$word',1)";
                    }
                    DB_Query( $sql );
               }
            }
        }
    }

    /* Log Search Phrases */
    $searchTerm = addslashes( $searchTerm );
    $result = DB_count( $_TABLES['http_referer_phrases'], 'phrase', $searchTerm );
    if( $result > 0 )
    {
        $sql = "UPDATE {$_TABLES['http_referer_phrases']} SET counthits = counthits + 1 WHERE "
             . "phrase='$searchTerm'";
    } else {
        $sql = "INSERT INTO {$_TABLES['http_referer_phrases']} VALUES ('$searchTerm', 1)";
    }
    DB_Query( $sql );
}


/** Strips a url down to the domain part.
  * @param url The url to strip
  * @return string
  */
function http_referer_get_display( $url )
{
    $position = strstr( $url, 'http://' ) + 7;
    if( $position > 0 )
    {
        $newurl = substr( $url, $position, strlen( $url ) );
        $positionslash = strpos( $newurl, '/' );
        if( $positionslash )
        {
            return substr( $url, 0, $positionslash + 7 );
        } else {
            return substr( $url, 0, 50 );
        }
    } else {
        return substr( $url, 0, 50 );
    }
}

/** Strips out the search phrase from a url, if it's a recognised search engine
  * @param url The URL To parse
  * @return string a link to the search on google.
  */
function http_referer_get_search( $url )
{
    global $_CONF;
    reset( $_CONF['http_referer_qss'] );
    while( list( $regexp, $qsitem ) = each( $_CONF['http_referer_qss'] ) )
    {
        if( eregi( $regexp, $url ) )
        {
            $aurl = parse_url( $url );
            $querystring = $aurl['query'];
            $querystring = explode( "&", $querystring );
            while( list( , $value ) = each( $querystring ) )
            {
                $item = explode( "=", $value );
                if( $item[0] == $qsitem )
                {
                    if( trim( $item[1] ) != '' )
                    {
                        $phrase = urldecode( $item[1] );
                        return "<a href=\"http://www.google.com/search?q={$item[1]}\">$phrase</a>";
                    }
                }
            }
        }
    }
}

/**
  * Gets a list of HTTP_REFERERs stored in the db table <prefix>http_referer
  * displays this all wrapped in blocks, linking to the referer.
  */
function http_referer_list()
{
    global $_TABLES, $LANG_HR, $_CONF;
    $display = COM_startBlock( $LANG_HR['http_referer'] );
    $sql = "SELECT * FROM {$_TABLES['http_referer']}";
    $result = DB_query ($sql);
    $referers = DB_numRows ($result);

    if ($referers > 0)
    {
        $display .= '<table><tr><td><b>URL</b></td><td><b>Search</b></td><td>'
                 . '<b>IP</b></td><td><b>Time</b></td>';
        if( SEC_hasRights( 'spamx.admin' ) )
        {
        	$display .= '<td><b>Blacklist</b></td>';
        }
        $display .= "</tr>\n";
        for ($j = 1; $j <= $referers; $j++)
        {
            $referer = DB_fetchArray ($result);
            $display .= "<tr><td><b>$j.</b> <a href=\"{$referer[1]}\" target=\"_blank\">"
                     .http_referer_get_display( $referer[1] )."</a></td><td>"
                     .http_referer_get_search( $referer[1] )."</td><td>"
                     .$referer[2]."</td><td>".$referer[3]."</td>";
           	if( SEC_hasRights( 'spamx.admin' ) )
           	{
            	$display .= '<td><a href="'.$_CONF['site_admin_url'].'/plugins/spamx/'
        					.'index.php?command=EditBlackList&action=Add%20Entry&entry='
        					.urlencode( $referer[1] ).'">Add</a></td>';
        		}
        		$display .= "</tr>\n";
        }
        if( SEC_hasRights( 'httpreferer.delete' ) )
        {
        	$display .= "<tr><td colspan=\"4\" align=\"center\"><a href=\"?op=delete\">Delete HTTP_REFERERS</a></td></tr>";
        }
        $display .= "</table>";
    } else {
        $display .= $LANG_HR['no_referers'];
    }
    $display .= COM_endBlock();
    return $display ;
}

/**
  * Gets a list of search phrases stored in the db table http_referer_phrases
  * displays this all wrapped in blocks, linking to the search.
  */
function http_referer_list_phrases()
{
  global $_TABLES, $LANG_HR, $_CONF;
  if( ( $_REQUEST['page'] == '' ) || !(is_numeric( $_REQUEST['page'] )) )
  {
  	$page = 1;
  } else {
  	$page = $_REQUEST['page'];
  }

  if( $page == 1 )
  {
  	$start = 0;
  } else {
  	$start = ($page - 1) * $_CONF['http_referer_page_limit'];
  }

  $count = DB_count( $_TABLES['http_referer_phrases'] );

  if( $start >= $count )
  {
  	$start = $count - $_CONF['http_referer_page_limit'];
  }

  $pages  = $count / $_CONF['http_referer_page_limit'];

  $display = COM_startBlock( $LANG_HR['http_referer_phrases'] );
  $sql = "SELECT * FROM {$_TABLES['http_referer_phrases']} ORDER BY counthits DESC LIMIT $start, {$_CONF['http_referer_page_limit']}";
  $result = DB_query ($sql);
  $phrases = DB_numRows ($result);

  if ($phrases > 0)
  {
    for ($j = 1; $j <= $phrases; $j++) {
      $p = DB_fetchArray ($result);
      $display .= '<b>';
      $display .= ($j + $start);
      $display .= '</b> '.stripslashes($p['phrase'])." ( {$p['counthits']} )<br>\n";
    }
    $display .= COM_printPageNavigation(  $_CONF['site_admin_url'].'/plugins/http_referer/index.php?op=listphrases', $page, $pages );
  } else {
    $display .= $LANG_HR['no_phrases'];
  }
  $display .= COM_endBlock();
  return $display ;
}

/**
  * Gets a list of search words stored in the db table http_referer_words
  * displays this all wrapped in blocks, linking to the search.
  */
function http_referer_list_words()
{
  global $_TABLES, $LANG_HR, $_CONF;

  if( ( $_REQUEST['page'] == '' ) || !(is_numeric( $_REQUEST['page'] )) )
  {
  	$page = 1;
  } else {
  	$page = $_REQUEST['page'];
  }

  if( $page == 1 )
  {
  	$start = 0;
  } else {
  	$start = ($page - 1) * $_CONF['http_referer_page_limit'];
  }

  $count = DB_count( $_TABLES['http_referer_words'] );

  if( $start >= $count )
  {
  	$start = $count - $_CONF['http_referer_page_limit'];
  }

  $pages  = $count / $_CONF['http_referer_page_limit'];


  $display = COM_startBlock( $LANG_HR['http_referer_words'] );
  $sql = "SELECT * FROM {$_TABLES['http_referer_words']} ORDER BY counthits DESC LIMIT $start, {$_CONF['http_referer_page_limit']}";
  $result = DB_query ($sql);
  $phrases = DB_numRows ($result);

  if ($phrases > 0)
  {
    for ($j = 1; $j <= $phrases; $j++) {
      $p = DB_fetchArray ($result);
      $display .= '<b>'.($j+$start).'</b> '.stripslashes($p['phrase'])." ( {$p['counthits']} Hits )<br>\n";
    }
    $display .= COM_printPageNavigation(  $_CONF['site_admin_url'].'/plugins/http_referer/index.php?op=listwords', $page, $pages );
  } else {
    $display .= $LANG_HR['no_words'];
  }
  $display .= COM_endBlock();
  return $display ;
}

/**
 * display a confirmation for emptying the HTTP_REFERER log
 */
function http_referer_delete_confirm()
{
    global $LANG_HR;
    $display = COM_StartBlock( $LANG_HR['http_referer'] );
    $display .= $LANG_HR['are_you_sure'].'<BR>'.$LANG_HR['are_you_sure_msg'];
    $display .= "<a href=\"?op=list\">{$LANG_HR['no']}</a> - <a href=\"?op=deleteconfirm\">{$LANG_HR['yes']}</a>";
    $display .= COM_endBlock();
    return $display;
}

/**
 * Delete all  HTTP_REFERERS
 */
function http_referer_delete()
{
  global $_TABLES,$LANG_HR;
  if( DB_Query("DELETE FROM {$_TABLES['http_referer']}") )
  {
    $display = COM_startBlock( $LANG_HR['delete_success'] );
    $display .= $LANG_HR['delete_success_msg'].COM_EndBlock();
  } else {
    $display = COM_startBlock( $LANG_HR['delete_fail'] );
    $display .= $LANG_HR['delete_fail_msg'].COM_EndBlock();
  }
  $display .= "<script language=\"javascript\">\n<!--\ndocument.location = '?op=list';\n//-->\n</script>\n";
  return $display;
}

/**
  * Displays the admin menu for the HTTP_REFERER plugin
  * @return Formatted HTML
  */
function http_referer_admin_menu()
{
    global $LANG_HR, $_CONF;
    $display = COM_startBlock( $LANG_HR['menu'] )."<center>";
    $display .= "<a href=\"{$_CONF['site_admin_url']}/plugins/http_referer/"
              . "index.php?op=\">List HTTP_REFERERs</a> - <a href=\""
              . "{$_CONF['site_admin_url']}/plugins/http_referer/index.php?op="
              . "listphrases\">{$LANG_HR['list_phrases']}</a> - <a href=\""
              . "{$_CONF['site_admin_url']}/plugins/http_referer/index.php?op="
              . "listwords\">{$LANG_HR['list_words']}</a><br>\n";
    $display .= "</center>".COM_endBlock();
    return $display;
}

/**
  * phpblock to list the last x HTTP_REFERER entries. Based on Jeff Bearer's
  * function.
  * @return formatted html
  */
function phpblock_http_referer_list()
{
    global $_CONF, $_TABLES, $LANG_HR;
    $sql = "SELECT * FROM {$_TABLES['http_referer']} ORDER BY tstamp DESC "
         . " LIMIT {$_CONF['http_referer_block_limit']}";
    $result = DB_Query( $sql );
    $nrows = DB_numrows( $result );
    if( $nrows > 0 )
    {
        $i = 1;
        while( $referer = DB_fetchArray( $result ) )
        {
            $display .= "<b>$i.</b> <a href=\"{$referer[1]}\" target=\"_blank\">"
                  . http_referer_get_display( $referer[1] ) . "</a><br>\n";
            $i++;
        }
    } else {
        $display .= $LANG_HR['no_referers'];
    }
    return $display;
}

/**
  * phpblock to list the top x search phrases entries. Based on Jeff Bearer's
  * function.
  * @return formatted html
  */
function phpblock_http_referer_list_phrases()
{
    global $_CONF, $_TABLES, $LANG_HR;
    $sql = "SELECT phrase,counthits FROM {$_TABLES['http_referer_phrases']} "
         . "ORDER BY counthits DESC LIMIT {$_CONF['http_referer_block_limit']}";
    $result = DB_Query( $sql );
    $nrows = DB_numrows( $result );
    if( $nrows > 0 )
    {
        $i = 1;
        while( $referer = DB_fetchArray( $result ) )
        {
            $display .= "<b>$i.</b> ".stripslashes($referer['phrase'])
                      . " ( {$referer['counthits']} )<br>\n";
            $i++;
        }
    } else {
        $display .= $LANG_HR['no_phrases'];
    }
    return $display;
}

/**
  * phpblock to list the top x search phrases entries. Based on Jeff Bearer's
  * function.
  * @return formatted html
  */
function phpblock_http_referer_list_words()
{
    global $_CONF, $_TABLES, $LANG_HR;
    $sql = "SELECT phrase,counthits FROM {$_TABLES['http_referer_words']} "
         . "ORDER BY counthits DESC LIMIT {$_CONF['http_referer_block_limit']}";
    $result = DB_Query( $sql );
    $nrows = DB_numrows( $result );
    if( $nrows > 0 )
    {
        $i = 1;
        while( $referer = DB_fetchArray( $result ) )
        {
            $display .= "<b>$i.</b> ".stripslashes($referer['phrase'])
                      . " ( {$referer['counthits']} )<br>\n";
            $i++;
        }
    } else {
        $display .= $LANG_HR['no_words'];
    }
    return $display;
}


/**
  * str_replace_once replaces first occurence of needle in haystack and replaces
  * with replace. Taken from http://uk.php.net/manual/en/function.str-replace.php
  * @param $needle item to find and replace
  * @param $replace what to replace it with
  * @param $haystack where to replace it
  * @return $haystack with $needle's first occurence replaced with $haystack
  */
function str_replace_once($needle, $replace, $haystack) {
    // Looks for the first occurence of $needle in $haystack
    // and replaces it with $replace.
    $pos = strpos($haystack, $needle);
    if ($pos === false) {
        // Nothing found
        return $haystack;
    }
    return substr_replace($haystack, $replace, $pos, strlen($needle));
}

function plugin_chkVersion_http_referer()
{
	global $_HR_CONF;
	return $_HR_CONF['version'] = '1.2';
}


/**
  * Parses every entry in HTTP_REFERER table to test the search engine shit.
  * Strongly recomend you never call this, unless testing my plugin on a NON
  * production environment
  */
//function _http_referer_TEST()
//{
//    global $_TABLES;
//    $display = COM_startBlock( 'TESTING SEARCHENGINE REFERER SHIT' );
//
//    $sql = "SELECT * FROM {$_TABLES['http_referer']}";
//    $result = DB_Query( $sql );
//    $nrows = DB_numrows( $result );
//    if( $nrows > 0 )
//    {
//        $display .= "Checking $nrows rows<br>\n";
//        for( $i = 0; $i < $nrows; $i++ )
//        {
//            $A = DB_fetchArray( $result );
//            $display .= http_referer_check_queries( $A['referer'], 1);
//        }
//    } else {
//        $display .= "No test data";
//    }
//    $display .= COM_endblock();
//    return $display;
//}

/******************************************************************************/
/*  Process the HTTP_REFERER if this plugin is enabled                        */
/******************************************************************************/
if( $_CONF['http_referer_logging'] == 1 )
{
  http_referer_log();
}

?>
